#
# spec file for package NetworkManager-l2tp
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pppd_plugin_dir %(rpm -ql ppp | grep -m1 pppd/[0-9]*)
Name:           NetworkManager-l2tp
Version:        1.2.8
Release:        lp150.2.20
Summary:        NetworkManager VPN support for L2TP and L2TP/IPsec
License:        GPL-2.0-or-later
Group:          Productivity/Networking/System
URL:            https://github.com/nm-l2tp/network-manager-l2tp
Source0:        https://github.com/nm-l2tp/network-manager-l2tp/archive/%{version}/network-manager-l2tp-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gettext
BuildRequires:  grep
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  ppp-devel
BuildRequires:  pkgconfig(NetworkManager) >= 1.2.0
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnm) >= 1.2.0
BuildRequires:  pkgconfig(libnm-glib) >= 1.2.0
BuildRequires:  pkgconfig(libnm-glib-vpn) >= 1.2.0
BuildRequires:  pkgconfig(libnm-gtk) >= 1.2.0
BuildRequires:  pkgconfig(libnm-util) >= 1.2.0
BuildRequires:  pkgconfig(libnma) >= 1.2.0
BuildRequires:  pkgconfig(libsecret-1)
Requires:       NetworkManager >= 1.2.0
Requires:       xl2tpd
%requires_eq    ppp
Recommends:     %{name}-lang
Recommends:     strongswan

%description
This package contains software for integrating L2TP and L2TP/IPsec
(L2TP over IPsec) VPN support with NetworkManager.

%package gnome
Summary:        NetworkManager VPN support for L2TP and L2TP/IPsec
Group:          Productivity/Networking/System
Requires:       %{name} = %{version}-%{release}
Requires:       NetworkManager-applet

%description gnome
This package contains software for integrating L2TP and L2TP/IPsec
(L2TP over IPsec) VPN support with NetworkManager.

%lang_package

%prep
%setup -q -n network-manager-l2tp-%{version}

%build
autoreconf -fi
intltoolize
%configure\
	--disable-static \
	--with-pppd-plugin-dir=%{pppd_plugin_dir} \
	--with-dist-version=%{version}-%{release}
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%files
%doc README.md NEWS
%{_libdir}/NetworkManager/libnm-vpn-plugin-l2tp.so
%{_libexecdir}/nm-l2tp-service
%dir %{_libexecdir}/NetworkManager
%dir %{_libexecdir}/NetworkManager/VPN
%{_libexecdir}/NetworkManager/VPN/nm-l2tp-service.name
%{_sysconfdir}/dbus-1/system.d/nm-l2tp-service.conf
%{pppd_plugin_dir}/nm-l2tp-pppd-plugin.so

%files gnome
%{_datadir}/appdata/network-manager-l2tp.metainfo.xml
%{_datadir}/gnome-vpn-properties/
%{_libdir}/NetworkManager/libnm-l2tp-properties.so*
%{_libdir}/NetworkManager/libnm-vpn-plugin-l2tp-editor.so
%{_libexecdir}/nm-l2tp-auth-dialog
%{_sysconfdir}/NetworkManager/VPN/nm-l2tp-service.name

%files lang -f %{name}.lang

%changelog
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Aug 12 2017 doug@uq.edu.au
- Update to version 1.2.8:
  * Updated translations.
  * Stops strongSwan service when a connection cannot be
    established.
- Changes from version 1.2.6:
  * Prefer building against stable libsecret API.
  * If L2TP port 1701 is already in use, no longer writes
    "leftprotoport=udp/l2tp" (which is equivalent to
    "leftprotoport=udp/1701") to the ipsec config file. This was
    done to ensures L2TP is encapsulated in IPsec.
- Changes from version 1.2.4:
  * Split libnm-vpn-plugin-pptp.so into a GTK-free core plugin
    usable by nmcli and a UI plugin for nm-applet and gnome
    components.
- Changes from version 1.2.2:
  * runtime test for strongwan or libreswan no longer performed if
    IPsec tickbox not ticked.
- Changes from version 1.2.0:
  * NetworkManager 1.1.x and 1.2.0 support
- Replace pkgconfig(libsecret-unstable) for pkgconfig(libsecret-1)
  BuildRequires following upstreams changes.
- Introduce GTK-free VPN plugin library to base package.
* Sun Jul 30 2017 doug@uq.edu.au
- Update to version 1.0.8:
  * Updated translations.
  * Stops strongSwan service when a connection cannot be
    established.
  * sets phase 1 (ike) and phase 2 (esp) ciphers for strongswan to
    the same as those used in version 1.0.4
- Changes from version 1.0.6:
  * If L2TP port 1701 is already in use, no longer writes
    "leftprotoport=udp/l2tp" (which is equivalent to
    "leftprotoport=udp/1701") to the ipsec config file. This was
    done to ensures L2TP is encapsulated in IPsec.
  * Uses UUID instead of PID for run-time generated filenames
  * No longer temporarily replaces system /etc/ipsec.secrets file
  * IPsec rekeying is now possible because the following file
    remains for the lifetime of the VPN connection :
    /etc/ipsec.d/nm-l2tp-ipsec-UUID.secrets
  * Following line is appended to /etc/ipsec.secrets if the include
    line is missing:
    include /etc/ipsec.d/*.secrets
  * Removed IPsec Group Name from user interface
  * Added IPsec Phase 1 (ike) & Phase 2 (esp) to user interface.
  * New timeout code for IPsec connection up script.
- Changes from version 1.0.4:
  * xl2tpd-1.3.7 compatibility fix for unrecognized option 'lock'.
  * /usr/sbin/ipsec runtime IPsec stack detection improved so that
    Openswan is rejected and not treated the same as openSwan.
  * Explictly check strongSwan connection has been established.
- Changes from version 1.0.2:
  * runtime test for strongwan or libreswan no longer performed if
    IPsec tickbox not ticked.
- Changes from version 1.0.0:
  * auth-dialog ported to libnm-gtk's NMAVpnPasswordDialog.
  * migrated from deprecated libgnome-keyring to libsecret.
  * Requires strongSwan or Libreswan for IPsec support,
    no longer works with Openswan.
  * Added MTU and MRU setting to PPP settings dialog box.
  * IPsec Group Name is now optional in IPsec dialog box.
- Drop icon install: as there is no icon file in the source
  anymore, nor is there a .desktop file that can make use of the
  icon.
- Drop --disable-more-warnings from configure line: no longer
  needed.
- Added %%%%check section.
- Replaced Requires strongswan with weaker Recommends strongswan.
- Replaced plus characters to recommended asterisk characters in
  changes file.
* Tue Oct 28 2014 dimstar@opensuse.org
- Update to version 0.9.8.7:
  * ipsec: missing curly braces led to always false return.
  * Updated translations.
* Fri Jul  4 2014 hillwood@linuxfans.org
- Update to version 0.9.8.6:
  * Bugfix: (security) don't start l2tp if IPsec enabled, but
    failed to start.
  * Bugfix: typo in nm-l2tp-service.name.
  * noccp pppd option added.
  * Minor locales fixes.
  * Require new versions of gtk+ and glib.
* Thu Oct 17 2013 hillwood@linuxfans.org
- Initial package, version 0.9.8:
  * Builds against the GNOME 3.8 versions of GLib and Gtk+.
  * Fix undefuned NM_L2TP_LOCALEDIR.
  * License file added.
  * Minor localization fixes.
